@@ -66,6 +66,11 @@ void	config(int argc, char **argv)
                                 memset (TrustDbDomainName, 0x00, 128);
                                 memcpy (TrustDbDomainName, pnt, strlen(pnt));
                         }
+                        else if (!memcmp (buff, "REPEATER_MODE", 13))
+                        {
+                                if (memcmp (pnt, "YES", 3) == 0)
+					repeater_mode = 1;
+                        }
 			else if (!memcmp (buff, "CMD_MODE", 8))
 			{
 				/* 1 stdin */
