@@ -2,6 +2,7 @@
 	Date	01/18/2014
 	Auther	Satoshi Yasuda	7M3TJZ/AD6GZ
 	Mod.
+	2014.01.21 V00.00
 
 */
 
@@ -233,10 +234,14 @@ int main(int argc, const char **argv)
 
 	/* PID の書き出し　/var/run/dsgwd_pi.pid  */
 	PidFile = fopen ("/var/run/dsgwd_pi.pid","w");
+	if (PidFile == NULL)
+	{
+		printf ("must run on supper user\n");
+		exit(-1);
+	}
 	fprintf (PidFile, "%d\n",(int)getpid());
 	fclose (PidFile);
 
-
 	cmdmode = 0;
 	ConnectWait = FALSE;
 	FirstHeaderSend = FALSE;
@@ -245,6 +250,7 @@ int main(int argc, const char **argv)
 	AckTimeOut = 0;
 	RelaySW = FALSE;
 	respFlags = RespNULL;
+	repeater_mode = 0;
 
 	config (argc, (char **)argv);
 
@@ -278,6 +284,11 @@ int main(int argc, const char **argv)
 
 	rf_qid = mq_open ("/dstar_rf", O_RDWR | O_CREAT, 
 		S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH, &rf_mattr);
+printf ("debug %d\n",rf_qid);
+if (rf_qid == -1)
+{
+	printf ("open error on mq_open %d\n",errno);
+}
 
         /* define mq attribute */
         inet_mattr.mq_flags = O_NONBLOCK;
@@ -369,7 +380,6 @@ int main(int argc, const char **argv)
 	if (width < udpSocket) width = udpSocket;
 	if (width < cmdin) width = cmdin;
 	width++;
-
 	while (1){
 		readOk = Mask;
 		if (ConnectWait) FD_CLR(rf_qid, &readOk);
@@ -393,6 +403,7 @@ int main(int argc, const char **argv)
 						RelaySW = TRUE;
 						ConnectWait = FALSE;
 						FirstHeaderSend = TRUE;
+						AckTimeOut = 0;
 						printf ("Change to Relay Mode\n");
 					}
 				}
